# A2A Net

[![PyPI - Version](https://img.shields.io/pypi/v/a2anet.svg)](https://pypi.org/project/a2anet)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/a2anet.svg)](https://pypi.org/project/a2anet)

-----

A Python package that makes implementing the A2A protocol easy

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install a2anet
```

## License

`a2anet` is distributed under the terms of the [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html) license.
